# Velocity of sound

# Objective

Calculate the velocity of sound by measuring the pressure variation with distance. Sound travels as a series of compressions and rarefactions. Figure ↓(b) shows the High and Low pressure regions along the direction of travel, along with output of a pressure sensor at corresponding positions.

We can display the pressure variation at any point with respect to the variation at the starting point. The phase of the microphone output changes as you change its distance from the Piezo. Moving by one wavelength changes the phase by 360 degrees. If the phase changes by X degrees for ΔD cm change in distance, the wavelength is given by λ= (360 × ΔD) ⁄X. The velocity of sound can be calculated by multiplying the frequency with this.

Figure 5.1 (a) schematic (b)compressions et expansions along the direction of sound.

# Procedure

- Set frequency to resonant maximum by measuring the frequency response 5.1↑
- Keep the Piezo facing the microphone, on the same axis
- Enable measurement
- Adjust the distance to make both the traces in Phase
- Change the distance to make them 180 degree out of phase, that distance is half wave length.

# Discussion

At 3500 Hz, for a 2 cm change in distance the phase changed from 176 to 102. Using the equation, v=f× (360 × ΔD) ⁄X, v= 3500 × (360 × 2) ⁄ (176102) = 34054cm⋅s1. It is important to keep the mic and the Piezo disc on the same axis, for accurate results.